@@ -48,7 +48,7 @@ struct _XfceGtkActionEntry
    * Replacement for the deprecated GtkActionEntry
    * The idea is to provide a fixed list of XfceGtkActionEntrys
    * - use 'xfce_gtk_translate_action_entries' once to translate the list
-   * - use 'xfce_gtk_accel_group_append' once to register the provided accelerators
+   * - use 'xfce_gtk_accel_map_add_entries' once to register the provided accelerators
    * - use 'xfce_gtk_get_action_entry_by_id' to find a single entry, e.g. by using a enumeration
    * - use 'xfce_gtk_***_new_from_action_entry' to create the specific menu- or tool-items from the entry
   */
@@ -113,10 +113,15 @@ GtkWidget                *xfce_gtk_toggle_menu_item_new_from_action_entry (const
 GtkWidget                *xfce_gtk_tool_button_new_from_action_entry      (const XfceGtkActionEntry *action_entry,
                                                                            GObject                  *callback_param,
                                                                            GtkToolbar               *toolbar_to_append_item);
-GtkAccelGroup            *xfce_gtk_accel_group_append                     (GtkAccelGroup            *accel_group,
+void                      xfce_gtk_accel_map_add_entries                  (const XfceGtkActionEntry *action_entries,
+                                                                           guint                     n_action_entries);
+void                      xfce_gtk_accel_group_connect_action_entries     (GtkAccelGroup            *accel_group,
                                                                            const XfceGtkActionEntry *action_entries,
                                                                            guint                     n_action_entries,
                                                                            gpointer                  callback_data);
+void                      xfce_gtk_accel_group_disconnect_action_entries  (GtkAccelGroup            *accel_group,
+                                                                           const XfceGtkActionEntry *action_entries,
+                                                                           guint                     n_action_entries);
 const XfceGtkActionEntry *xfce_gtk_get_action_entry_by_id                 (const XfceGtkActionEntry *action_entries,
                                                                            guint                     n_action_entries,
                                                                            guint                     id);
@@ -149,6 +154,8 @@ gboolean                  xfce_widget_reparent                            (GtkWi
 const gchar              *xfce_icon_name_from_desktop_id                  (const gchar               *desktop_id);
 
 GIcon                    *xfce_gicon_from_name                            (const gchar               *name);
+void                      xfce_gtk_menu_item_set_accel_label              (GtkMenuItem               *menu_item,
+                                                                           const gchar               *accel_path);
 
 G_END_DECLS
 
